#! /bin/sh
#-------------------------------------------------------------
#procedure to update users who were previously over the limit.
#-------------------------------------------------------------
#setting the basic definition
. `dirname $0`/../shell/version.sh
#-----------------------------------------------------
#loading the variable value
. $BASE/etc/$APPNAME-$VERSION/$APPNAME.conf

MGBYTES="(1024*1024)"
#-------------------------------------------------------------
#setting the Variable
#first the Data-base type
if [ -z "$DB_TYPE" ] ; then
  DB_TYPE=POSTGRESQL;
  fi

#Then the data-base name
if [ -z "$DB_NAME" ] ; then
  DB_NAME=$APPNAME;
  fi

#-------------------------------------------------------------
case "$DB_TYPE" in
  "POSTGRESQL"  )
     if [ ! -z "$DB_PORT" ] ; then
       SQLPORT="-p $DB_PORT"
       fi
     if [ ! -z "$DB_HOST" ] ; then
       SQLHOST="-h $DB_HOST"
       fi
     SQL="psql -t -q $SQLPORT $SQLHOST"
     ;;
  "MYSQL"       )
     if [ ! -z "$DB_PORT" ] ; then
       SQLPORT="-P $DB_PORT"
       fi
     if [ ! -z "$DB_HOST" ] ; then
       SQLHOST="-h $DB_HOST"
       fi
     SQL="mysql -s -u $APPNAME $SQLPORT $SQLHOST"
     ;;
  esac

#----------------------------------------------
#procedure to probe data-base qith an SQL request
#as $1 parametere
prob_db()

{
case "$DB_TYPE" in
  "POSTGRESQL"  )
     echo "$1" | psql -t -q  -A -F ' ' $SQLPORT $SQLHOST $DB_NAME
     ;;
  "MYSQL"       )
     echo "$1" | mysql -s -u $APPNAME $SQLPORT $SQLHOST $DB_NAME
     ;;
  esac
}

#----------------------------------------------
#avoiding any race condition
LOCK=$BASE/var/lock/$APPNAME-$VERS/checkcount.lck
trap "rm -f $LOCK ; exit 1" 1 2 3 15
if [ -f $LOCK ] ; then
# the lock file already exists, so what to do?
  if [ "$(ps `cat $LOCK` | wc -l)" -gt 1 ]; then
    # process is still running
    echo "$0: quit at start: lingering process `cat $LOCK`"
    exit 1
  else
    # process not running, but lock file not deleted?
    echo " $0: orphan lock file warning. Lock file deleted."
    rm -f $LOCK
    fi
  fi
echo $$ > $LOCK
#----------------------------------------------
#positionning over the right directory
cd $BASE/var/spool/$APPNAME-$VERS/mails

#scanning users who previously where over or at max.
prob_db "SELECT username FROM overuse" |			\
while read -r USERNAME
  do
  user=`echo $USERNAME | cut -d'@' -f1`;
  dom=`echo $USERNAME | cut -d'@' -f2-`;
case "$DB_TYPE" in
  "POSTGRESQL"  )
  spe_user=`echo $user | sed -e "s/'/''/" `
  spe_USERNAME=`echo $USERNAME | sed -e "s/'/''/" `
  du_user=`echo $user | sed -e 's/'\''/\\\\'\''/'`
     ;;
  "MYSQL"       )
  spe_user=`echo $user | sed -e 's/'\''/\\\\'\''/'`
  spe_USERNAME=`echo $USERNAME | sed -e 's/'\''/\\\\'\''/'`
  du_user=`echo $user | sed -e 's/'\''/\\\\'\''/'`
     ;;
  esac
  mxmgbytes=`prob_db "SELECT mxmgbytes FROM userprofile		\
			WHERE prfid=(SELECT prfid FROM users WHERE username='$spe_USERNAME')"`
    (
    cd $dom
    usedmgbytes=`du -m -s $user| cut -f1`
    if [ -z $usedmgbytes ] ; then
      usedmgbytes=0
      fi
    if [ $usedmgbytes -gt $mxmgbytes ] ; then
      ratio=`echo "scale=5 ; $usedmgbytes/$mxmgbytes" | bc`
      prob_db "UPDATE overuse SET ratio=$ratio WHERE username='$spe_USERNAME'"
      else
      prob_db "DELETE FROM overuse WHERE username='$spe_USERNAME'"
      fi
    prob_db "UPDATE users SET usedbytes=$usedmgbytes WHERE username='$spe_USERNAME'"
    prob_db "UPDATE users SET usedbytes=usedbytes*$MGBYTES WHERE username='$spe_USERNAME'"
    )
  done
#remove lock before exiting
rm -f $LOCK


